@@ -1,22 +1,10 @@
-/*****************************************************************************
- * Copyright (c) 2007 Piyush verma <piyush.verma@gmail.com>                  *
- * Copyright 2007 Andreas Pakulat <apaku@gmx.de>                             *
- * Copyright 2011-2014 Sven Brauch <svenbrauch@googlemail.com>               *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2007 Piyush verma <piyush.verma@gmail.com>
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2011-2014 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PYTHON_DECLARATIONBUILDER_H
 #define PYTHON_DECLARATIONBUILDER_H
@@ -90,6 +78,7 @@ protected:
     void visitFunctionDefinition(FunctionDefinitionAst* node) override;
     void visitAssignment(AssignmentAst* node) override;
     void visitAnnotationAssignment(AnnotationAssignmentAst* node) override;
+    void visitAssignmentExpression(AssignmentExpressionAst* node) override;
     void visitFor(ForAst* node) override;
     void visitImport(ImportAst* node) override;
     void visitImportFrom(ImportFromAst* node) override;
