@@ -1,23 +1,9 @@
-/***************************************************************************
- *   This file is part of KDevelop                                         *
- *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
- *   Copyright 2012 Patrick Spendrin <ps_ml@gmx.de>                        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2012 Patrick Spendrin <ps_ml@gmx.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 // The Python 3.4 Language Reference was used as basis for this AST
 
@@ -55,7 +41,6 @@ namespace Python {
     class ExceptionHandlerAst;
     class AliasAst;
     class ComprehensionAst;
-    class SliceAstBase;
     class SliceAst;
 }
 
@@ -102,7 +87,6 @@ public:
         NameConstantAstType,
         CallAstType,
         AttributeAstType,
-        ExtendedSliceAstType,
         DictionaryComprehensionAstType,
         BooleanOperationAstType,
         BinaryOperationAstType,
@@ -127,10 +111,8 @@ public:
         TupleAstType,
         YieldFromAstType,
         ComprehensionAstType,
-
         SliceAstType,
         EllipsisAstType,
-        IndexAstType,
         AssignmentExpressionAstType,
         LastExpressionType, // keep this at the end of the expr ast list
 
@@ -671,7 +653,7 @@ class KDEVPYTHONPARSER_EXPORT SubscriptAst : public ExpressionAst {
 public:
     SubscriptAst(Ast* parent);
     ExpressionAst* value;
-    SliceAstBase* slice;
+    ExpressionAst* slice;
     ExpressionAst::Context context;
 };
 
@@ -696,18 +678,12 @@ public:
     ExpressionAst::Context context;
 };
 
-/** Slice classes **/
-class KDEVPYTHONPARSER_EXPORT SliceAstBase : public Ast {
-public:
-    SliceAstBase(Ast* parent, AstType type);
-};
-
-class KDEVPYTHONPARSER_EXPORT EllipsisAst : public SliceAstBase {
+class KDEVPYTHONPARSER_EXPORT EllipsisAst : public ExpressionAst {
 public:
     EllipsisAst(Ast* parent);
 };
 
-class KDEVPYTHONPARSER_EXPORT SliceAst : public SliceAstBase {
+class KDEVPYTHONPARSER_EXPORT SliceAst : public ExpressionAst {
 public:
     SliceAst(Ast* parent);
     ExpressionAst* lower;
@@ -715,17 +691,6 @@ public:
     ExpressionAst* step;
 };
 
-class KDEVPYTHONPARSER_EXPORT ExtendedSliceAst : public SliceAstBase {
-public:
-    ExtendedSliceAst(Ast* parent);
-    QList<SliceAst*> dims;
-};
-
-class KDEVPYTHONPARSER_EXPORT IndexAst : public SliceAstBase {
-public:
-    IndexAst(Ast* parent);
-    ExpressionAst* value;
-};
 
 /** Independent classes **/
 
